==> hibiscus.js-1.2.2.tgz: package/notification/notification.service.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { Overlay } from '@angular/cdk/overlay';
import { ApplicationRef, ComponentFactoryResolver, Injectable, Injector } from '@angular/core';
import { MessageBaseService } from '../message/message.service';
import { NotificationContainerComponent } from './notification-container.component';
var NotificationService = /** @class */ (function (_super) {
    __extends(NotificationService, _super);
    function NotificationService(overlay, injector, cfr, appRef) {
        return _super.call(this, overlay, NotificationContainerComponent, injector, cfr, appRef, 'notification-') || this;
    }
    // Shortcut methods
    // Shortcut methods
    NotificationService.prototype.success = 
    // Shortcut methods
    function (title, content, options) {
        return this.createMessage({ type: 'success', title: title, content: content }, options);
    };
    NotificationService.prototype.error = function (title, content, options) {
        return this.createMessage({ type: 'error', title: title, content: content }, options);
    };
    NotificationService.prototype.info = function (title, content, options) {
        return this.createMessage({ type: 'info', title: title, content: content }, options);
    };
    NotificationService.prototype.warning = function (title, content, options) {
        return this.createMessage({ type: 'warning', title: title, content: content }, options);
    };
    NotificationService.prototype.blank = function (title, content, options) {
        return this.createMessage({ type: 'blank', title: title, content: content }, options);
    };
    NotificationService.prototype.create = function (type, title, content, options) {
        return this.createMessage({ type: type, title: title, content: content }, options);
    };
    // For content with template
    // For content with template
    NotificationService.prototype.template = 
    // For content with template
    function (template, options) {
        return this.createMessage({ template: template }, options);
    };
    NotificationService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    NotificationService.ctorParameters = function () { return [
        { type: Overlay, },
        { type: Injector, },
        { type: ComponentFactoryResolver, },
        { type: ApplicationRef, },
    ]; };
    return NotificationService;
}(MessageBaseService));
export { NotificationService };

==> hibiscus.js-1.2.3.tgz: package/notification/notification.service.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { Overlay } from '@angular/cdk/overlay';
import { ApplicationRef, ComponentFactoryResolver, Injectable, Injector } from '@angular/core';
import { MessageBaseService } from '../message/message.service';
import { NotificationContainerComponent } from './notification-container.component';
var NotificationService = (function (_super) {
    __extends(NotificationService, _super);
    function NotificationService(overlay, injector, cfr, appRef) {
        return _super.call(this, overlay, NotificationContainerComponent, injector, cfr, appRef, 'notification-') || this;
    }
    NotificationService.prototype.success = function (title, content, options) {
        return this.createMessage({ type: 'success', title: title, content: content }, options);
    };
    NotificationService.prototype.error = function (title, content, options) {
        return this.createMessage({ type: 'error', title: title, content: content }, options);
    };
    NotificationService.prototype.info = function (title, content, options) {
        return this.createMessage({ type: 'info', title: title, content: content }, options);
    };
    NotificationService.prototype.warning = function (title, content, options) {
        return this.createMessage({ type: 'warning', title: title, content: content }, options);
    };
    NotificationService.prototype.blank = function (title, content, options) {
        return this.createMessage({ type: 'blank', title: title, content: content }, options);
    };
    NotificationService.prototype.create = function (type, title, content, options) {
        return this.createMessage({ type: type, title: title, content: content }, options);
    };
    NotificationService.prototype.template = function (template, options) {
        return this.createMessage({ template: template }, options);
    };
    NotificationService.decorators = [
        { type: Injectable },
    ];
    NotificationService.ctorParameters = function () { return [
        { type: Overlay, },
        { type: Injector, },
        { type: ComponentFactoryResolver, },
        { type: ApplicationRef, },
    ]; };
    return NotificationService;
}(MessageBaseService));
export { NotificationService };
